# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Guard
Version:	1.023
Release:	27.%{__distinit}%{__distvers}
Summary:	Safe cleanup blocks
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Guard
Source0:	https://cpan.metacpan.org/authors/id/M/ML/MLEHMANN/Guard-%{version}.tar.gz
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Exporter)
BuildRequires:	perl(warnings)
BuildRequires:	perl(XSLoader)
# Test Suite
# (no additional dependencies)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Exporter)
Requires:	perl(warnings)
Requires:	perl(XSLoader)

# Avoid provides from private shared objects
%{?perl_default_filter}

%description
This module implements so-called "guards". A guard is something (usually an
object) that "guards" a resource, ensuring that it is cleaned up when expected.

%prep
%setup -q -n Guard-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license COPYING
%doc Changes README
%{perl_vendorarch}/auto/Guard/
%{perl_vendorarch}/Guard.pm
%{_mandir}/man3/Guard.3*

%changelog
* Tue Jul 11 2023 Paul Howarth <paul@city-fan.org> - 1.023-27
- Perl 5.38 rebuild

* Fri Apr 21 2023 Paul Howarth <paul@city-fan.org> - 1.023-26
- Use SPDX-format license tag
- Use %%license unconditionally

* Tue May 31 2022 Paul Howarth <paul@city-fan.org> - 1.023-24
- Perl 5.36 rebuild

* Fri May 21 2021 Paul Howarth <paul@city-fan.org> - 1.023-21
- Perl 5.34 rebuild

* Mon Jan 18 2021 Paul Howarth <paul@city-fan.org> - 1.023-19
- Use %%license unconditionally

* Wed Jun 24 2020 Paul Howarth <paul@city-fan.org> - 1.023-18
- Perl 5.32 rebuild

* Thu May 30 2019 Paul Howarth <paul@city-fan.org> - 1.023-15
- Perl 5.30 rebuild

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 1.023-12
- Perl 5.28 rebuild

* Mon Aug  7 2017 Paul Howarth <paul@city-fan.org> - 1.023-10
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Tue Jun 13 2017 Paul Howarth <paul@city-fan.org> - 1.023-8
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Tue May 17 2016 Paul Howarth <paul@city-fan.org> - 1.023-6
- BR: perl-devel and perl-generators where available
- Simplify find commands with -empty and -delete

* Fri Nov 21 2014 Paul Howarth <paul@city-fan.org> - 1.023-1
- Update to 1.023
  - Work around backwards compatibility breakage in perl 5.22 (removal of
    PL_sv_objcount)
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible
- Classify buildreqs by usage

* Tue Jul 23 2013 Paul Howarth <paul@city-fan.org> - 1.022-5
- Perl 5.18 rebuild

* Fri Jun  8 2012 Paul Howarth <paul@city-fan.org> - 1.022-3
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Sat Jul  2 2011 Paul Howarth <paul@city-fan.org> - 1.022-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Sat Jul  2 2011 Paul Howarth <paul@city-fan.org> - 1.022-1
- Update to 1.022:
  - Document how () after the function name overrides the prototype
  - Improve documentation, fix the examples
- Nobody else likes macros for commands

* Mon Jan 24 2011 Paul Howarth <paul@city-fan.org> - 1.021-5
- Import from Fedora

* Fri Dec 17 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.021-4
- Rebuild to fix problems with vendorarch/lib (#661697)

* Sun May 02 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.021-3
- Mass rebuild with perl 5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 1.021-2
- Rebuild against perl 5.10.1

* Sun Nov 08 2009 Nicolas Chuavet <kwizart@fedoraproject.org> - 1.021-1
- Specfile autogenerated by cpanspec 1.78
